@@ -14,7 +14,8 @@ import logging
 import os
 import copy
 
-from botocore.vendored import requests
+from botocore.awsrequest import AWSRequest
+from botocore.httpsession import URLLib3Session
 from botocore.exceptions import ProfileNotFound
 from awscli.compat import six
 
@@ -73,6 +74,10 @@ PARAMFILE_DISABLED = set([
 
     'machinelearning.predict.predict-endpoint',
 
+    'api.mediatailor.put-playback-configuration.ad-decision-server-url',
+    'api.mediatailor.put-playback-configuration.slate-ad-url',
+    'api.mediatailor.put-playback-configuration.video-content-source-url',
+
     'rds.copy-db-cluster-snapshot.pre-signed-url',
     'rds.create-db-cluster.pre-signed-url',
     'rds.copy-db-snapshot.pre-signed-url',
@@ -221,7 +226,8 @@ def get_file(prefix, path, mode):
 
 def get_uri(prefix, uri):
     try:
-        r = requests.get(uri)
+        session = URLLib3Session()
+        r = session.send(AWSRequest('GET', uri).prepare())
         if r.status_code == 200:
             return r.text
         else:
